@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-05-19 11:33:16
-@LastEditTime: 2021-08-31 17:09:48
+@LastEditTime: 2021-08-31 19:13:28
 @LastEditors: HuangJianYi
 :description: 用户处理
 """
@@ -20,6 +20,7 @@ from seven_cloudapp.models.db_models.price.price_gear_model import *
 from seven_cloudapp.models.db_models.gear.gear_value_model import *
 from seven_cloudapp.models.db_models.ip.ip_series_model import *
 from seven_cloudapp.models.db_models.prop.prop_log_model import *
+from seven_cloudapp.models.db_models.exchange.exchange_info_model import *
 
 from seven_cloudapp.handlers.client.user import UserHandler
 from seven_cloudapp.handlers.client.user import LoginHandler
@@ -558,29 +559,30 @@ class GivePropHandler(SevenBaseHandler):
         update_sql = ""
         if not user_detail:
             return self.reponse_json_error("Error", "道具卡数量不足")
-        give_config_json = self.json_loads(act_dict["give_config_json"])
-        if not give_config_json:
+        exchange_info_model = ExchangeInfoModel(context=self)
+        exchange_info = exchange_info_model.get_entity("act_id=%s and is_release=1 and goods_type=%s", params=[act_id, prop_type])
+        if not exchange_info:
             return self.reponse_json_error("Error", "无法进行赠送")
 
         prop_give_total = prop_give_model.get_total("open_id=%s and act_id=%s and prop_type=%s and create_date_int=%s", params=[open_id, act_id, prop_type, SevenHelper.get_now_day_int()])
         if prop_type == 3:
             if user_detail.tips_card_count <= 0:
                 return self.reponse_json_error("Error", "提示卡数量不足")
-            if prop_give_total >= int(give_config_json["tips_limit_count"]):
+            if prop_give_total >= exchange_info.day_limit:
                 return self.reponse_json_error("Error", "提示卡赠送数量达到上限")
             history_value = user_detail.tips_card_count
             update_sql = "tips_card_count=tips_card_count-1"
         elif prop_type == 4:
             if user_detail.redraw_card_count <= 0:
                 return self.reponse_json_error("Error", "重抽卡数量不足")
-            if prop_give_total >= int(give_config_json["redraw_limit_count"]):
+            if prop_give_total >= exchange_info.day_limit:
                 return self.reponse_json_error("Error", "重抽卡赠送数量达到上限")
             history_value = user_detail.redraw_card_count
             update_sql = "redraw_card_count=redraw_card_count-1"
         else:
             if user_detail.perspective_card_count <= 0:
                 return self.reponse_json_error("Error", "透视卡数量不足")
-            if prop_give_total >= int(give_config_json["perspective_limit_count"]):
+            if prop_give_total >= exchange_info.day_limit:
                 return self.reponse_json_error("Error", "透视卡赠送数量达到上限")
             history_value = user_detail.perspective_card_count
             update_sql = "perspective_card_count=perspective_card_count-1"
