@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-04-19 15:11:42
-@LastEditTime: 2021-08-31 10:39:00
+@LastEditTime: 2021-08-31 19:09:43
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -59,11 +59,10 @@ class ActInfo:
         self.shakebox_tips = ""  # 摇盒提示
         self.exceed_tips = ""  # 超出次数提示
         self.shakebox_tips_num = 0  # 摇盒提示次数
-        self.give_config_json = ""  # 转赠配置json
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'app_id', 'owner_open_id', 'act_name', 'act_type', 'theme_id', 'store_url', 'close_word', 'share_desc', 'rule_desc', 'integral_rule', 'start_date', 'end_date', 'refund_count', 'is_black', 'sort_index', 'menu_configed', 'finish_progress', 'is_release', 'is_task', 'is_throw', 'is_del', 'join_ways', 'is_fictitious', 'currency_type', 'task_currency_type', 'lottery_value', 'release_date', 'create_date', 'modify_date', 'index_desc', 'shakebox_tips', 'exceed_tips', 'shakebox_tips_num', 'give_config_json']
+        return ['id', 'app_id', 'owner_open_id', 'act_name', 'act_type', 'theme_id', 'store_url', 'close_word', 'share_desc', 'rule_desc', 'integral_rule', 'start_date', 'end_date', 'refund_count', 'is_black', 'sort_index', 'menu_configed', 'finish_progress', 'is_release', 'is_task', 'is_throw', 'is_del', 'join_ways', 'is_fictitious', 'currency_type', 'task_currency_type', 'lottery_value', 'release_date', 'create_date', 'modify_date', 'index_desc', 'shakebox_tips', 'exceed_tips', 'shakebox_tips_num']
 
     @classmethod
     def get_primary_key(self):
