@@ -2,8 +2,8 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-16 14:38:22
-:LastEditTime: 2021-07-27 15:47:12
-:LastEditors: HuangJingCan
+@LastEditTime: 2021-08-31 17:12:59
+@LastEditors: HuangJianYi
 :Description: 潮玩盲盒基础路由
 """
 # 框架引用
@@ -135,6 +135,8 @@ def seven_cloudapp_ppmt_route():
         (r"/client/exchange_list", exchange.ExchangeListHandler),
         (r"/client/user_detail", user.GetUserDetailHandler),
         (r"/client/integral_list", user.GetIntegralListHandler),
+        (r"/client/give_prop", user.GivePropHandler),
+        (r"/client/get_prop_give", user.GetPropGiveHandler),
         (r"/client/lottery_all", lottery.LotteryAllHandler),
         (r"/client/use_reset_card", lottery.UseResetCardHandler),
         (r"/client/use_perspective_card", lottery.UsePerspectiveCardHandler),
